Writers
=======

Writers are the final step in the |project| processing chain. They take
gridded data, scale it to fit in an output format, and write the data to
one or more output files. These files can then be provided to a visualization
tool that is optimized for viewing the data.

.. toctree-filt::
    :maxdepth: 1

    :polar2grid:awips_tiled
    :polar2grid:binary
    :polar2grid:geotiff
    :polar2grid:hdf5
    :geo2grid:geotiff
